@@ -1,16 +1,3 @@
-"""
-Scenario:
-- there is a certain number of patients at start day_total_cases
-- each day there are more new patients based on doubles_in_days
-- each day some patients will die based on case_fatality_rate
-- each day some patients are released based on mean_duration
-    - all patients that meet mean_duration and did not die are released
-- some patients can be admitted based on current available capacity
-    - such patients will be added to day_total_cases
-- some patients may not be admittable due to lack of current capacity
-    - such patients will die
-"""
-
 import collections
 import random
 import math
@@ -87,7 +74,7 @@ def hospital_manager(env,
             _b_ = [0] * int((1 - hospital.icu_properties[icu_type]['fatality_rate']) * 100)
             dist = _a_ + _b_
             patient_die = random.choice(dist)
-            out_time = abs(np.random.normal(0, env.now + hospital.icu_properties[icu_type]['stay_duration']))
+            out_time = abs(np.random.normal(env.now, hospital.icu_properties[icu_type]['stay_duration']))
             icu = ICU(icu_type, out_time, patient_die)
 
             hospital.daily_accepted_total[icu_type] += 1
@@ -221,11 +208,11 @@ def patients_arrivals(env,
                                              icu_entity['icu_type'],
                                              hospital,
                                              hours_in_day))
+
+            if env.now != 0 and hour % hours_in_day == 0:
                 env.process(update_icu_departments(env,
                                                    hospital,
                                                    update_frequency_in_hours))
-
-            if env.now != 0 and hour % hours_in_day == 0:
                 env.process(update_statistic(env,
                                              hospital,
                                              hours_in_day))
@@ -282,22 +269,22 @@ def generate_random_icu_list(icu_count: int,
 
 def simulate(p: dict = {
              'initial_patient_count':  120,
-             'require_ventilation_rate':  0.3,
+             'ventilation_rate':  0.3,
              'days_to_simulate':  20,
              'doubles_in_days': 10,
-             'standard_icu_capacity': 400,
-             'ventilated_icu_capacity': 230,
-             'standard_icu_fatality_rate': 0.4,
-             'ventilated_icu_fatality_rate': 0.8,
-             'standard_icu_stay_duration': 10,
-             'ventilated_icu_stay_duration': 10},
+             'standard_capacity': 400,
+             'ventilated_capacity': 230,
+             'standard_cfr': 0.4,
+             'ventilated_cfr': 0.8,
+             'standard_duration': 10,
+             'ventilated_duration': 10},
              random_seed=None):
 
-    starting_standard_icu_count = int(p['initial_patient_count'] * (1 - p['require_ventilation_rate']))
-    starting_ventilated_icu_count = int(p['initial_patient_count'] * p['require_ventilation_rate'])
+    starting_standard_icu_count = int(p['initial_patient_count'] * (1 - p['ventilation_rate']))
+    starting_ventilated_icu_count = int(p['initial_patient_count'] * p['ventilation_rate'])
 
-    _a_ = starting_standard_icu_count > p['standard_icu_capacity']
-    _b_ = starting_ventilated_icu_count > p['ventilated_icu_capacity']
+    _a_ = starting_standard_icu_count > p['standard_capacity']
+    _b_ = starting_ventilated_icu_count > p['ventilated_capacity']
 
     if (_a_ or _b_):
         raise Exception("Starting amount can't be bigger then capacity!")
@@ -306,8 +293,8 @@ def simulate(p: dict = {
     update_frequency_in_hours = 1
 
     hours_to_simulate = p['days_to_simulate'] * hours_in_day
-    standard_icu_stay_duration = p['standard_icu_stay_duration'] * hours_in_day
-    ventilated_icu_stay_duration = p['ventilated_icu_stay_duration'] * hours_in_day
+    standard_icu_stay_duration = p['standard_duration'] * hours_in_day
+    ventilated_icu_stay_duration = p['ventilated_duration'] * hours_in_day
 
     if random_seed is not None:
         random.seed(random_seed)
@@ -319,26 +306,26 @@ def simulate(p: dict = {
     departments = [ICU_Types.standard_icu.name, ICU_Types.ventilated_icu.name]
 
     _temp_standard_icu_list_ = generate_random_icu_list(starting_standard_icu_count,
-                                                        p['standard_icu_stay_duration'],
+                                                        p['standard_duration'],
                                                         ICU_Types.standard_icu.name,
                                                         hours_in_day)
 
     _temp_ventilated_icu_list_ = generate_random_icu_list(starting_ventilated_icu_count,
-                                                          p['ventilated_icu_stay_duration'],
+                                                          p['ventilated_duration'],
                                                           ICU_Types.ventilated_icu.name,
                                                           hours_in_day)
 
-    _temp_standard_icu_dict_ = {'capacity': p['standard_icu_capacity'], 'icu_list': _temp_standard_icu_list_}
-    _temp_ventilated_icu_dict_ = {'capacity': p['ventilated_icu_capacity'], 'icu_list': _temp_ventilated_icu_list_}
+    _temp_standard_icu_dict_ = {'capacity': p['standard_capacity'], 'icu_list': _temp_standard_icu_list_}
+    _temp_ventilated_icu_dict_ = {'capacity': p['ventilated_capacity'], 'icu_list': _temp_ventilated_icu_list_}
 
     departments_capacity = {ICU_Types.standard_icu.name: _temp_standard_icu_dict_,
                             ICU_Types.ventilated_icu.name: _temp_ventilated_icu_dict_}
 
-    _temp_standard_icu_meta_ = {'fatality_rate': p['standard_icu_fatality_rate'],
-                                'stay_duration': p['standard_icu_stay_duration']}
+    _temp_standard_icu_meta_ = {'fatality_rate': p['standard_cfr'],
+                                'stay_duration': standard_icu_stay_duration}
 
-    _temp_ventilated_icu_meta_ = {'fatality_rate': p['ventilated_icu_fatality_rate'],
-                                  'stay_duration': p['ventilated_icu_stay_duration']}
+    _temp_ventilated_icu_meta_ = {'fatality_rate': p['ventilated_cfr'],
+                                  'stay_duration': ventilated_icu_stay_duration}
 
     icu_properties = {ICU_Types.standard_icu.name: _temp_standard_icu_meta_,
                       ICU_Types.ventilated_icu.name: _temp_ventilated_icu_meta_}
@@ -351,7 +338,7 @@ def simulate(p: dict = {
     hospital = Hospital(hospital_resource_manager,
                         departments,
                         departments_capacity,
-                        p['require_ventilation_rate'],
+                        p['ventilation_rate'],
                         daily_refused_total,
                         daily_accepted_total,
                         daily_released_total,
@@ -371,111 +358,3 @@ def simulate(p: dict = {
     env.run(until=hours_to_simulate)
 
     return hospital.statistic
-
-
-def stats_to_dataframe(results):
-
-    import pandas as pd
-
-    # pd.set_option("display.max_rows", 5)
-    # pd.set_option("display.max_columns", 7)
-    # pd.set_option('display.width', None)
-
-    out = []
-    cols = []
-
-    # get day key
-    for day in results.keys():
-
-        _temp_ = []
-        cols = []
-
-        # get metric name key
-        for metric in results[day].keys():
-
-            _temp_.append(results[day][metric]['standard_icu'])
-            _temp_.append(results[day][metric]['ventilated_icu'])
-
-            cols.append('standard_icu_' + metric)
-            cols.append('ventilated_icu_' + metric)
-
-        out.append(_temp_)
-
-    df = pd.DataFrame(out)
-    df.columns = cols
-
-    return df
-
-
-def _dump_dictionary_(obj):
-    if isinstance(obj, dict):
-        for k, v in obj.items():
-            if hasattr(v, '__iter__'):
-                print(k)
-                _dump_dictionary_(v)
-            else:
-                print('%s : %s' % (k, v))
-    elif isinstance(obj, list):
-        for v in obj:
-            if hasattr(v, '__iter__'):
-                _dump_dictionary_(v)
-            else:
-                print(v)
-    else:
-        print(obj)
-
-
-def params(show_params=False):
-    
-    '''
-    Creates input parameters for simulate().
-    '''
-    
-    import random
-    import numpy as np
-    
-    # set max capacity 
-    _capacity_ = random.choice(list(range(200, 1000, 50)))
-    
-    # set the fraction of ventilation capacity
-    _ventilated_capacity_ = (np.random.normal(1, 0.01) * .5)
-    
-    # set standard case fatality rate
-    _fatality_rate_ = round(random.choice(np.arange(0.2, 0.6, .01)), 2)
-    
-    # set ventilated case fatality rate
-    _ventilated_fatality_factor_ = random.choice(np.arange(1.3, 1.7, 0.01))
-    
-    # set a multiplier for ventilated stay duration
-    _ventilated_duration_factor_ = random.choice(np.arange(1, 1.2, 0.01))
-    
-    # initialize values
-    initial_patient_count = 120
-    days_to_simulate = 50
-    doubles_in_days = round(random.choice(np.arange(2.0, 12.0, .1)), 2)
-    require_ventilation_rate = round(random.choice(np.arange(.3, .8, .01)), 3)
-    standard_icu_capacity = int(_capacity_ * (1 - _ventilated_capacity_))
-    ventilated_icu_capacity = int(_capacity_ * _ventilated_capacity_)
-    standard_icu_fatality_rate = float(_fatality_rate_)
-    ventilated_icu_fatality_rate = round(_fatality_rate_ * (np.random.normal(1, 0.01) * _ventilated_fatality_factor_), 2)
-    standard_icu_stay_duration = int(random.choice(list(range(8, 25, 1))))
-    ventilated_icu_stay_duration = int(standard_icu_stay_duration * (np.random.normal(1, 0.01) * _ventilated_duration_factor_))
-    
-    # generates the input parameters
-    p = {'initial_patient_count': initial_patient_count,
-         'days_to_simulate': days_to_simulate,
-         'doubles_in_days': doubles_in_days,
-         'require_ventilation_rate': require_ventilation_rate,
-         'standard_icu_capacity': standard_icu_capacity,
-         'ventilated_icu_capacity': ventilated_icu_capacity,
-         'standard_icu_fatality_rate': standard_icu_fatality_rate,
-         'ventilated_icu_fatality_rate': ventilated_icu_fatality_rate,
-         'standard_icu_stay_duration': standard_icu_stay_duration,
-         'ventilated_icu_stay_duration': ventilated_icu_stay_duration}
-    
-    # print out the params
-    if show_params:
-        for key in p.keys():
-            print(key,p[key])
-    
-    return p
